import { ForkOptions } from '../interface';
import type { IEventBus } from '@midwayjs/event-bus';
export declare abstract class AbstractForkManager<T, ClusterOptions extends ForkOptions> {
    readonly options: ClusterOptions;
    private reforks;
    private disconnectCount;
    private unexpectedCount;
    private disconnects;
    private hub;
    protected workers: Set<T>;
    protected eventBus: IEventBus<T>;
    private isClosing;
    protected constructor(options: ClusterOptions);
    start(): Promise<void>;
    protected tryToRefork(oldWorker: T): void;
    /**
     * allow refork
     */
    protected allowRefork(): boolean;
    /**
     * uncaughtException default handler
     */
    protected onerror(err: any): void;
    /**
     * unexpectedExit default handler
     */
    protected onUnexpected(worker: T, code: any, signal: any): void;
    /**
     * reachReforkLimit default handler
     */
    protected onReachReforkLimit(): void;
    protected killWorker(worker: any, timeout: any): Promise<void>;
    close(timeout?: number): Promise<void>;
    abstract createWorker(oldWorker?: T): T;
    abstract bindWorkerDisconnect(listener: (worker: T) => void): void;
    abstract bindWorkerExit(listener: (worker: T, code: any, signal: any) => void): void;
    abstract getWorkerId(worker: T): string;
    abstract isWorkerDead(worker: T): boolean;
    abstract closeWorker(worker: T): any;
    abstract createEventBus(): IEventBus<T>;
}
//# sourceMappingURL=base.d.ts.map