"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClusterManager = void 0;
const cp_1 = require("@midwayjs/event-bus/dist/cp");
const base_1 = require("./base");
const path_1 = require("path");
const cluster = require('cluster');
const util_1 = require("util");
const debug = (0, util_1.debuglog)('midway:bootstrap');
class ClusterManager extends base_1.AbstractForkManager {
    constructor(options = {}) {
        super(options);
        this.options = options;
        options.args = options.args || [];
        options.execArgv = options.execArgv || [];
        if ((0, path_1.extname)(this.options.exec) === '.ts') {
            options.execArgv.push(...['--require', 'ts-node/register']);
        }
        debug('Init cluster manager with options: %j', options);
    }
    createWorker() {
        if (cluster['setupPrimary']) {
            cluster['setupPrimary'](this.options);
        }
        else if (cluster['setupMaster']) {
            cluster['setupMaster'](this.options);
        }
        console.log('----cluster=', process.pid);
        return cluster.fork();
    }
    bindWorkerDisconnect(listener) {
        debug('Bind cluster.disconnect event');
        cluster.on('disconnect', listener);
    }
    bindWorkerExit(listener) {
        debug('Bind cluster.exit event');
        cluster.on('exit', listener);
    }
    getWorkerId(worker) {
        return String(worker.process.pid);
    }
    isWorkerDead(worker) {
        return worker.isDead();
    }
    closeWorker(worker) {
        worker.kill('SIGTERM');
    }
    createEventBus() {
        return new cp_1.ChildProcessEventBus();
    }
}
exports.ClusterManager = ClusterManager;
//# sourceMappingURL=cp.js.map