"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ThreadManager = void 0;
const path_1 = require("path");
const base_1 = require("./base");
let threads = null;
let shareEnv = null;
let Worker = null;
let ThreadEventBus = null;
try {
    // eslint-disable-next-line node/no-unsupported-features/node-builtins
    threads = require('worker_threads');
    shareEnv = threads.SHARE_ENV;
    Worker = threads.Worker;
    ThreadEventBus = require('@midwayjs/event-bus').ThreadEventBus;
}
catch (e) {
    // ignore not support worker_threads
}
class ThreadManager extends base_1.AbstractForkManager {
    constructor(options = {}) {
        super(options);
        this.options = options;
        options.argv = options.argv || [];
        options.execArgv = options.execArgv || [];
    }
    createWorker() {
        let w;
        let content = `
    require(${JSON.stringify(this.options.exec)});
  `;
        // 当前是 ts 环境
        if ((0, path_1.extname)(this.options.exec) === '.ts') {
            content = `
    require("ts-node/register/transpile-only");
    ${content}
    `;
            w = new Worker(content, { eval: true, env: shareEnv });
            w['_originThreadId'] = String(w.threadId);
            this.options.logger.info('new worker thread with ts-node, threadId = %s.', this.getWorkerId(w));
        }
        else {
            w = new Worker(content, { eval: true, env: shareEnv });
            this.options.logger.info('new worker thread, threadId = %s.', this.getWorkerId(w));
        }
        w.on('exit', code => {
            this.exitListener(w, code);
        });
        return w;
    }
    bindWorkerDisconnect(listener) {
        // this.disconnectListener = listener;
    }
    bindWorkerExit(listener) {
        this.exitListener = listener;
    }
    getWorkerId(worker) {
        return worker['_originThreadId'] || String(worker.threadId);
    }
    isWorkerDead(worker) {
        return false;
    }
    async closeWorker(worker) {
        await worker.terminate();
    }
    createEventBus() {
        return new ThreadEventBus();
    }
}
exports.ThreadManager = ThreadManager;
//# sourceMappingURL=thread.js.map